@@ -33,9 +33,7 @@
 #include "property.hrc"
 #include "convert.hxx"
 
-/** === begin UNO includes === **/
 #include <com/sun/star/xsd/WhiteSpaceTreatment.hpp>
-/** === end UNO includes === **/
 #include <tools/debug.hxx>
 #include <tools/datetime.hxx>
 #include <rtl/math.hxx>
@@ -505,7 +503,7 @@ namespace xforms
             break;
 
         default:
-            OSL_ENSURE( false, "OValueLimitedType::_explainInvalid: unknown reason!" );
+            OSL_FAIL( "OValueLimitedType::_explainInvalid: unknown reason!" );
             break;
         }
 
